# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Info directory maintained using file triggers from Fedora 28 onwards
# https://fedoraproject.org/wiki/Packaging:Scriptlets#Texinfo
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
%global no_file_triggers 1
%else
%global no_file_triggers 0
%endif

# Also build with cmake from Fedora 32 onwards
%if (0%{?rhel} && 0%{?rhel} <= 8) || (0%{?fedora} && 0%{?fedora} <= 31)
%global cmake_build 0
%else
%global cmake_build 1
%endif

# Set to 1 if re-generating autotools patch
%global regen_autotools 0

Name:		check
Version:	0.15.2
Release:	1.0.cf.%{__distinit}%{__distvers}
Summary:	A unit test framework for C
License:	LGPLv2+
URL:		http://libcheck.github.io/check/
Source0:	https://github.com/libcheck/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:		check-0.11.0-info-in-builddir.patch
Patch1:		check-0.12.0-fp.patch
Patch10:	check-0.15.2-autotools.patch
%if %{cmake_build}
BuildRequires:	cmake
%endif
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	pkgconfig
BuildRequires:	sed
%if 0%{?fedora} > 20
BuildRequires:	pkgconfig(libsubunit)
%endif
# For documentation
BuildRequires:	graphviz
BuildRequires:	texinfo
%if 0%{?fedora} > 17 || 0%{?rhel} > 6
BuildRequires:	texlive-tex
%endif

# Info directory maintained using file triggers from Fedora 28 onwards
# https://fedoraproject.org/wiki/Packaging:Scriptlets#Texinfo
# Same for linker cache
%if %{no_file_triggers}
Requires(post):		info, /sbin/ldconfig
Requires(preun):	info
%endif

# There was no need for Fedora to do a sub-package for this
Obsoletes:	check-checkmk < %{version}-%{release}
Provides:	check-checkmk = %{version}-%{release}

# These are needed to regenerate the autotools patch
%if %{regen_autotools}
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	libtool
%endif

%description
Check is a unit test framework for C. It features a simple interface for
defining unit tests, putting little in the way of the developer. Tests
are run in a separate address space, so Check can catch both assertion
failures and code errors that cause segmentation faults or other signals.
The output from unit tests can be used within source code editors and IDEs.

%package devel
Summary:	Libraries and headers for developing programs with check
License:	LGPLv2+ and BSD
Requires:	pkgconfig
Requires:	%{name} = %{version}-%{release}

%description devel
Libraries and headers for developing programs with check.

%package static
Summary:	Static libraries of check
License:	LGPLv2+

%description static
Static libraries of check.

# TODO move to new cmake macros when they are backported to f32 properly
%global _vpath_builddir $RPM_BUILD_DIR/check-%{version}/cmake_build

%prep
%setup -q

# Fix detection of various time-related function declarations
sed	-e '/DECLS(\[a/s|)|,,,[AC_INCLUDES_DEFAULT\n[#include <time.h>\n #include <sys/time.h>]]&|' \
	-i configure.ac

# Fix for modern autotools
%patch0 -p1 -b .info-in-builddir

# Fix test failures due to varying floating point behaviour across platforms
%patch1 -p0

# Examples for checkmk documentation
cp -a checkmk/examples checkmk-examples

# Get rid of version control files
find . -name .cvsignore -delete

# Upstream expects us to do this as they do not ship a configure script
%if %{regen_autotools}
cd ..
cp -a check-%{version} check-%{version}.orig
cd check-%{version}
autoreconf --install
cd ..
# Note: this patch needs some hand-tweaking to fix file ordering, remove autom4te.cache etc.
diff -urp --unidirectional-new-file check-%{version}.orig check-%{version} > check-%{version}-autotools.patch
cd check-%{version}
%else
%patch10
chmod -c +x configure
%endif

%build
# The autotools build does not create the cmake files, but the cmake build
# does not create the info or aclocal files; hence, from Fedora 32 onwards,
# do both and combine the results

mkdir autotools_build
cd autotools_build
%global _configure ../configure

%configure --disable-timeout-tests

# Get rid of undesirable hardcoded rpaths
# Work around libtool reordering -Wl,--as-needed after all the libraries
sed	-e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
	-e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
	-e 's|CC="\(.*g..\)"|CC="\1 -Wl,--as-needed"|' \
	-i libtool

make %{?_smp_mflags}
cd -

%if %{cmake_build}
mkdir cmake_build
cd cmake_build
%cmake -DCHECK_ENABLE_TIMEOUT_TESTS:BOOL=OFF ..
%{make_build}
cd -
%endif

%install
cd autotools_build
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Remove files we don't want packaged
%if %{cmake_build}
rm -rf %{buildroot}%{_libdir}
%else
rm -f %{buildroot}%{_libdir}/*.la
%endif
rm -f %{buildroot}%{_infodir}/dir
rm -rf %{buildroot}%{_defaultdocdir}/check
cd -

%if %{cmake_build}
cd cmake_build
%{make_install}
cd -
%endif

%check
%ifnarch s390x
LD_LIBRARY_PATH=%{buildroot}%{_libdir} make -C autotools_build check
%endif

# Don't need to package the sh, log or trs files
# when we scoop the other checkmk/test files for doc
rm -rf checkmk/test/check_checkmk*
# these files are empty
rm -rf checkmk/test/empty_input

# ldconfig scriptlets and info directories replaced by RPM File Triggers from Fedora 28
%if %{no_file_triggers}
%post
/sbin/ldconfig
/sbin/install-info %{_infodir}/check.info %{_infodir}/dir || :

%preun
[ $1 = 0 ] && /sbin/install-info --delete %{_infodir}/check.info %{_infodir}/dir || :

%postun -p /sbin/ldconfig
%endif

%files
%if 0%{?_licensedir:1}
%license COPYING.LESSER
%else
%doc COPYING.LESSER
%endif
%doc AUTHORS NEWS README.md
%doc THANKS TODO
%{_libdir}/libcheck.so.0
%{_libdir}/libcheck.so.0.*
%{_infodir}/check*

%files devel
# LGPLv2+
%doc doc/example
%{_includedir}/check.h
%{_includedir}/check_stdint.h
%if %{cmake_build}
%{_libdir}/cmake/check/
%endif
%{_libdir}/libcheck.so
%{_libdir}/pkgconfig/check.pc
%{_datadir}/aclocal/check.m4
# BSD
%doc checkmk-examples checkmk/test
%{_bindir}/checkmk
%{_mandir}/man1/checkmk.1*

#check used to be static only, hence this.
%files static
%if 0%{?_licensedir:1}
%license COPYING.LESSER
%else
%doc COPYING.LESSER
%endif
%{_libdir}/libcheck.a

%changelog
* Mon Aug 10 2020 Paul Howarth <paul@city-fan.org> - 0.15.2-1.0.cf
- Update to 0.15.2 (see NEWS for details)

* Tue Aug  4 2020 Paul Howarth <paul@city-fan.org> - 0.15.1-3.0.cf
- Add an extra NULL argument to the deprecated fail* macros
  https://github.com/libcheck/check/commit/82540c54

* Sun Aug  2 2020 Paul Howarth <paul@city-fan.org> - 0.15.1-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Paul Howarth <paul@city-fan.org> - 0.15.1-1.0.cf
- Update to 0.15.1 (see NEWS for details)

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 0.15.0-2.0.cf
- Update to 0.15.0 (see NEWS for details)
- Add -formatspec patch (GH#271)
- Build with both cmake and autotools from Fedora 32 onwards

* Sat Feb  1 2020 Paul Howarth <paul@city-fan.org> - 0.14.0-3.0.cf
- Disable tests on s390x

* Thu Jan 30 2020 Paul Howarth <paul@city-fan.org> - 0.14.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Tue Jan 28 2020 Paul Howarth <paul@city-fan.org> - 0.14.0-1.0.cf
- Update to 0.14.0 (see NEWS for details)

* Tue Dec  3 2019 Paul Howarth <paul@city-fan.org> - 0.13.0-2.0.cf
- Don't package obsolete ChangeLog file (#1778647)

* Tue Oct 22 2019 Paul Howarth <paul@city-fan.org> - 0.13.0-1.0.cf
- Update to 0.13.0 (see NEWS for details)

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 0.12.0-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb  1 2019 Paul Howarth <paul@city-fan.org> - 0.12.0-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Jul 24 2018 Paul Howarth <paul@city-fan.org> - 0.12.0-3.1.cf
- Disable unreliable timeout tests (sometimes fail on busy builders)

* Tue Jul 17 2018 Paul Howarth <paul@city-fan.org> - 0.12.0-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb  9 2018 Paul Howarth <paul@city-fan.org> - 0.12.0-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Feb  5 2018 Paul Howarth <paul@city-fan.org> - 0.12.0-1.0.cf
- Update to 0.12.0 (see NEWS for details)
- Drop ldconfig calls in scriptlets from Fedora 28 onwards

* Thu Aug  3 2017 Paul Howarth <paul@city-fan.org> - 0.11.0-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Paul Howarth <paul@city-fan.org> - 0.11.0-3.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Feb 10 2017 Paul Howarth <paul@city-fan.org> - 0.11.0-2.0.cf
- Update to 0.11.0 (see NEWS for details)
- Upstream moved from sourceforge to github

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 0.10.0-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Aug  3 2015 Paul Howarth <paul@city-fan.org> - 0.10.0-1.0.cf
- Update to 0.10.0 (see NEWS for details)

* Fri Jun 19 2015 Paul Howarth <paul@city-fan.org> - 0.9.14-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Paul Howarth <paul@city-fan.org> - 0.9.14-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jul 28 2014 Paul Howarth <paul@city-fan.org> - 0.9.14-1.0.cf
- Update to 0.9.14 (see NEWS for details)
- Use %%license where possible

* Sat Jun  7 2014 Paul Howarth <paul@city-fan.org> - 0.9.13-2.0.cf
- Update to 0.9.13 (see NEWS for details)

* Sat Apr 26 2014 Paul Howarth <paul@city-fan.org> - 0.9.12-2.0.cf
- Build with subunit support from Fedora 21 onwards
- Drop %%defattr, redundant since rpm 4.4

* Tue Jan 21 2014 Paul Howarth <paul@city-fan.org> - 0.9.12-1.0.cf
- Update to 0.9.12
  - Additional unit tests created for internal and external Check APIs
  - Check now compiled on Windows using MSVC when using CMake and NMake; all
    unit tests pass, though shell script based ones need to be run in the MSYS
    environment
  - Check now compiles on Windows using Visual Studio 10 when using CMake;
    check_check passes when run from Visual Studios
  - Always capture the start and end times of tests when using NO_FORK mode;
    previously the end time was not captured, resulting in arbitrary durations
    being recorded when tests failed (Bug #87)
  - Added additional configure script checks for support of timer_create() on
    the target system, which allows for OpenBSD to compile and run all Check's
    unit tests successfully
  - Added a unit test, check_mem_leaks, which can be used against valgrind to
    test for memory leaks (no memory leaks were found)
  - Added tcase_add_loop_test support in checkm (Patches #46)
  - Add support for logging in Test Anything Protocol (TAP) format
  - Refactor Check's assertions to be more like the assert() call in assert.h,
    in that static source code analyzers can use gcc attributes in the header
    to make assumptions about the flow of the code (see Feature Request #29)
  - Fix ck_assert_ptr_* causing const compilation warnings (Bug #91)

* Tue Nov  5 2013 Paul Howarth <paul@city-fan.org> - 0.9.11-1.0.cf
- Update to 0.9.11
  - Check's unit tests pass when compiled out of the source tree
  - Check compiles for Windows using the MinGW/msys environment (without using
    fork), and all unit tests pass
  - Check compiles for Windows using the Cygwin environment, and all unit tests
    pass
  - Check compiles for Windows using MinGW in Linux (without using fork), and
    all unit tests pass using wine 1.4
  - Check compiles for Windows using MinGW-w64 in Linux (without using fork),
    and all unit tests pass using wine 1.4
  - On systems without timer_settimer, use setitimer (if available) to get
    subsecond unit test timeouts; if setitimer is unavailable, fallback on
    alarm
- Drop aarch64 patch

* Mon Aug  5 2013 Paul Howarth <paul@city-fan.org> - 0.9.10-3.0.cf
- Fix detection of more time-related functions
- Note that checkmk is BSD-licensed
- Obsolete/provide Fedora's checkmk subpackage

* Sat Aug  3 2013 Paul Howarth <paul@city-fan.org> - 0.9.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> - 0.9.10-1
- Update to 0.9.10 (see NEWS for details)
- Drop upstreamed format patch

* Tue Mar 26 2013 Paul Howarth <paul@city-fan.org> - 0.9.9-3
- Move checkmk to the devel package
- Add aarch64 support (#925218)
- BR: pkgconfig
- Fix localtime_r detection
- Make sure we avoid bogus RPATHs

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 0.9.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Oct 23 2012 Paul Howarth <paul@city-fan.org> - 0.9.9-1
- Update to 0.9.9 (see NEWS for details)
- Drop patch for #821933, now upstream
- Package new checkmk tool and manpage
- Hardcode libcheck soname in %%files list to avoid nasty surprises in future

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 0.9.8-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 17 2012 Paul Howarth <paul@city-fan.org> - 0.9.8-5
- Add upstream patch to halt execution when running in CK_FORK=no mode and a
  test fails (#821933)

* Fri Oct  7 2011 Paul Howarth <paul@city-fan.org> - 0.9.8-4
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Dec 20 2010 Paul Howarth <paul@city-fan.org> - 0.9.8-3
- Import from Fedora

* Mon Nov 29 2010 Jerry James <loganjerry@gmail.com> - 0.9.8-2
- Add license file to -static package
- Remove BuildRoot tag

* Mon Sep 28 2009 Jerry James <loganjerry@gmail.com> - 0.9.8-1
- Update to 0.9.8

* Thu Aug  6 2009 Jerry James <loganjerry@gmail.com> - 0.9.6-5
- Support --excludedocs (bz 515933)
- Replace broken upstream info dir entry

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Apr  7 2009 Jerry James <loganjerry@gmail.com> - 0.9.6-3
- Add check-0.9.6-strdup.patch

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jan  6 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 0.9.6-1
- Update to 0.9.6

* Mon Dec  1 2008 Jerry James <loganjerry@gmail.com> - 0.9.5-3
- Fix unowned directory (bz 473635)
- Drop unnecessary BuildRequires
- Replace patches with addition of -fPIC to CFLAGS in the spec file
- Add some more documentation files

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.9.5-2.1
- Autorebuild for GCC 4.3

* Thu Aug  2 2007 Tom "spot" Callaway <tcallawa@redhat.com> 0.9.5-1
- 0.9.5 bump

* Fri Jul 14 2006 Jesse Keating <jkeating@redhat.com> - 0.9.3-5
- Rebuild

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 0.9.3-4.fc5.2
- Bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 0.9.3-4.fc5.1
- Rebuilt for new gcc4.1 snapshot and glibc changes

* Mon Dec 19 2005 Warren Togami <wtogami@redhat.com> 0.9.2-4
- Import into FC5 for gstreamer-0.10

* Fri Dec  2 2005 Tom "spot" Callaway <tcallawa@redhat.com> 0.9.2-3
- Enabled -fPIC to resolve bz 174313

* Sat Sep 17 2005 Tom "spot" Callaway <tcallawa@redhat.com> 0.9.2-2
- Get rid of the so file (not needed)
- Only make devel package

* Sun Aug 14 2005 Tom "spot" Callaway <tcallawa@redhat.com> 0.9.2-1
- Initial package for Fedora Extras
